@@ -1,10 +1,13 @@
 """Constants for the Z-Wave JS python library."""
+import sys
 from enum import Enum, IntEnum
 
 # minimal server schema version we can handle
-MIN_SERVER_SCHEMA_VERSION = 14
+MIN_SERVER_SCHEMA_VERSION = 15
 # max server schema version we can handle (and our code is compatible with)
-MAX_SERVER_SCHEMA_VERSION = 14
+MAX_SERVER_SCHEMA_VERSION = 15
+
+TYPING_EXTENSION_FOR_TYPEDDICT_REQUIRED = sys.version_info < (3, 9, 2)
 
 VALUE_UNKNOWN = "unknown"
 
